@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import gobject
-from ifaceswlib.interfaces.Abstract import AbstractInterface
+from advifswlib.interfaces.Abstract import AbstractInterface
 
 class GSMInterface(AbstractInterface):
 
